@@ -191,6 +191,8 @@ static void copy_uri_cb				(GtkAction	*action,
 						 TextView	*textview);
 static void add_uri_to_addrbook_cb 		(GtkAction	*action,
 						 TextView	*textview);
+static void reply_to_uri_cb 			(GtkAction	*action,
+						 TextView	*textview);
 static void mail_to_uri_cb 			(GtkAction	*action,
 						 TextView	*textview);
 static void copy_mail_to_uri_cb			(GtkAction	*action,
@@ -212,6 +214,7 @@ static GtkActionEntry textview_mail_popup_entries[] =
 {
 	{"TextviewPopupMail",			NULL, "TextviewPopupMail" },
 	{"TextviewPopupMail/Compose",		NULL, N_("Compose _new message"), NULL, NULL, G_CALLBACK(mail_to_uri_cb) },
+	{"TextviewPopupMail/ReplyTo",		NULL, N_("_Reply to this address"), NULL, NULL, G_CALLBACK(reply_to_uri_cb) },
 	{"TextviewPopupMail/AddAB",		NULL, N_("Add to _Address book"), NULL, NULL, G_CALLBACK(add_uri_to_addrbook_cb) },
 	{"TextviewPopupMail/Copy",		NULL, N_("Copy this add_ress"), NULL, NULL, G_CALLBACK(copy_mail_to_uri_cb) },
 };
@@ -342,6 +345,8 @@ TextView *textview_create(void)
 			"/Menus/TextviewPopupLink", "Copy", "TextviewPopupLink/Copy", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(textview->ui_manager, 
 			"/Menus/TextviewPopupMail", "Compose", "TextviewPopupMail/Compose", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(textview->ui_manager, 
+			"/Menus/TextviewPopupMail", "ReplyTo", "TextviewPopupMail/ReplyTo", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(textview->ui_manager, 
 			"/Menus/TextviewPopupMail", "AddAB", "TextviewPopupMail/AddAB", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(textview->ui_manager, 
@@ -452,16 +457,10 @@ static void textview_create_tags(GtkTextView *text, TextView *textview)
 				"foreground-gdk", &quote_colors[2],
 				NULL);
 	}
-#if GTK_CHECK_VERSION(2, 8, 0)
 	gtk_text_buffer_create_tag(buffer, "tags",
 			"foreground-gdk", &black,
 			"paragraph-background-gdk", &yellow,
 			NULL);
-#else
-	gtk_text_buffer_create_tag(buffer, "tags",
-			"foreground-gdk", &emphasis_color,
-			NULL);
-#endif
 	gtk_text_buffer_create_tag(buffer, "emphasis",
 			"foreground-gdk", &emphasis_color,
 			NULL);
@@ -501,19 +500,11 @@ void textview_init(TextView *textview)
 	textview_create_tags(GTK_TEXT_VIEW(textview->text), textview);
 }
 
-#if GTK_CHECK_VERSION(2, 8, 0)
  #define CHANGE_TAG_COLOR(tagname, colorfg, colorbg) { \
 	tag = gtk_text_tag_table_lookup(tags, tagname); \
 	if (tag) \
 		g_object_set(G_OBJECT(tag), "foreground-gdk", colorfg, "paragraph-background-gdk", colorbg, NULL); \
  }
-#else
- #define CHANGE_TAG_COLOR(tagname, colorfg, colorbg) { \
-	tag = gtk_text_tag_table_lookup(tags, tagname); \
-	if (tag) \
-		g_object_set(G_OBJECT(tag), "foreground-gdk", colorfg, NULL); \
- }
-#endif
 
 static void textview_update_message_colors(TextView *textview)
 {
@@ -858,7 +849,6 @@ void textview_show_error(TextView *textview)
 	TEXTVIEW_INSERT_LINK(_("'View Log'"), "sc://view_log", NULL);
 	TEXTVIEW_INSERT(_(" in the Tools menu for more information."));
 	textview_show_icon(textview, GTK_STOCK_DIALOG_ERROR);
-
 }
 
 void textview_show_mime_part(TextView *textview, MimeInfo *partinfo)
@@ -948,9 +938,16 @@ static void textview_write_body(TextView *textview, MimeInfo *mimeinfo)
 	if (textview->messageview->forced_charset)
 		charset = textview->messageview->forced_charset;
 	else {
+		/* use supersets transparently when possible */
 		charset = procmime_mimeinfo_get_parameter(mimeinfo, "charset");
 		if (charset && !strcasecmp(charset, CS_ISO_8859_1))
 			charset = CS_WINDOWS_1252;
+		else if (charset && !strcasecmp(charset, CS_X_GBK))
+			charset = CS_GB18030;
+		else if (charset && !strcasecmp(charset, CS_GBK))
+			charset = CS_GB18030;
+		else if (charset && !strcasecmp(charset, CS_GB2312))
+			charset = CS_GB18030;
 	}
 
 	textview_set_font(textview, charset);
@@ -1021,7 +1018,7 @@ static void textview_write_body(TextView *textview, MimeInfo *mimeinfo)
 			argv = strsplit_with_quote(buf, " ", 0);
 			close(1);
 			close(pfd[0]);
-			dup(pfd[1]);
+			rc = dup(pfd[1]);
 			rc = execvp(argv[0], argv);
 			close(pfd[1]);
 			g_print(_("The command to view attachment "
@@ -1224,6 +1221,7 @@ static void textview_make_clickable_parts(TextView *textview,
 		{"https://", strcasestr, get_uri_part,   make_uri_string},
 		{"ftp://",   strcasestr, get_uri_part,   make_uri_string},
 		{"sftp://",  strcasestr, get_uri_part,   make_uri_string},
+		{"gopher://",strcasestr, get_uri_part,   make_uri_string},
 		{"www.",     strcasestr, get_uri_part,   make_http_string},
 		{"mailto:",  strcasestr, get_uri_part,   make_uri_string},
 		{"@",        strcasestr, get_email_part, make_email_string}
@@ -1764,6 +1762,7 @@ static gboolean header_is_internal(Header *header)
 		 "X-Claws-Account-Id:", "X-Claws-Sign:", "X-Claws-Encrypt:", 
 		 "X-Claws-Privacy-System:", "X-Claws-End-Special-Headers:",
 		 "X-Sylpheed-Account-Id:", "X-Sylpheed-Sign:", "X-Sylpheed-Encrypt:", 
+		 "X-Claws-Auto-Wrapping:", "X-Claws-Auto-Indent:",
 		 "X-Sylpheed-Privacy-System:", "X-Sylpheed-End-Special-Headers:",
 		 NULL};
 	int i;
@@ -2671,7 +2670,8 @@ static gboolean textview_uri_button_pressed(GtkTextTag *tag, GObject *obj,
 			} 
 			return TRUE;
 		} else if (qlink && bevent->button == 1) {
-			textview_toggle_quote(textview, NULL, uri, FALSE);
+			if (prefs_common.hide_quoted)
+				textview_toggle_quote(textview, NULL, uri, FALSE);
 			return TRUE;
 		} else if (!g_ascii_strncasecmp(uri->uri, "mailto:", 7)) {
 			if (bevent->button == 3) {
@@ -2684,6 +2684,8 @@ static gboolean textview_uri_button_pressed(GtkTextTag *tag, GObject *obj,
 			} else {
 				PrefsAccount *account = NULL;
 				FolderItem   *folder_item = NULL;
+				Compose *compose;
+				
 				if (textview->messageview && textview->messageview->msginfo &&
 				    textview->messageview->msginfo->folder) {
 					
@@ -2694,7 +2696,9 @@ static gboolean textview_uri_button_pressed(GtkTextTag *tag, GObject *obj,
 					if (!account)
 						account = account_find_from_item(folder_item);
 				}
-				compose_new_with_folderitem(account, folder_item, uri->uri + 7);
+				compose = compose_new_with_folderitem(account,
+								folder_item, uri->uri + 7);
+				compose_check_for_email_account(compose);
 			}
 			return TRUE;
 		} else if (g_ascii_strncasecmp(uri->uri, "file:", 5)) {
@@ -3039,9 +3043,21 @@ static void add_uri_to_addrbook_cb (GtkAction *action, TextView *textview)
 	g_free(fromname);
 }
 
+static void reply_to_uri_cb (GtkAction *action, TextView *textview)
+{
+	ClickableText *uri = g_object_get_data(G_OBJECT(textview->mail_popup_menu),
+					   "menu_button");
+	if (!textview->messageview || !uri)
+		return;
+
+	compose_reply_to_address (textview->messageview,
+				  textview->messageview->msginfo, uri->uri+7);
+}
+
 static void mail_to_uri_cb (GtkAction *action, TextView *textview)
 {
 	PrefsAccount *account = NULL;
+	Compose *compose;
 	ClickableText *uri = g_object_get_data(G_OBJECT(textview->mail_popup_menu),
 					   "menu_button");
 	if (uri == NULL)
@@ -3055,10 +3071,11 @@ static void mail_to_uri_cb (GtkAction *action, TextView *textview)
 		if (folder_item->prefs && folder_item->prefs->enable_default_account)
 			account = account_find_from_id(folder_item->prefs->default_account);
 		
-		compose_new_with_folderitem(account, folder_item, uri->uri+7);
+		compose = compose_new_with_folderitem(account, folder_item, uri->uri+7);
 	} else {
-		compose_new(account, uri->uri + 7, NULL);
+		compose = compose_new(account, uri->uri + 7, NULL);
 	}
+	compose_check_for_email_account(compose);
 }
 
 static void copy_mail_to_uri_cb	(GtkAction *action, TextView *textview)
